summaryrefslogtreecommitdiffstats
path: root/chrome
diff options
context:
space:
mode:
authorben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-02-14 20:38:10 +0000
committerben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-02-14 20:38:10 +0000
commitf258bbe05f0e0ff5580639ff1ede4b6f80a3bd58 (patch)
treef48732f0e129f7f36fe8ab33b9732216623315be /chrome
parent182fe2f459b174b9c1de6520776ceb23f7d0f0de (diff)
downloadchromium_src-f258bbe05f0e0ff5580639ff1ede4b6f80a3bd58.zip
chromium_src-f258bbe05f0e0ff5580639ff1ede4b6f80a3bd58.tar.gz
chromium_src-f258bbe05f0e0ff5580639ff1ede4b6f80a3bd58.tar.bz2
Revert 74693. Changing approach.
git-svn-id: svn://svn.chromium.org/chrome/trunk/src@74849 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome')
-rw-r--r--chrome/browser/accessibility/browser_views_accessibility_browsertest.cc1
-rw-r--r--chrome/browser/aeropeek_manager.cc4
-rw-r--r--chrome/browser/automation/automation_provider_win.cc1
-rw-r--r--chrome/browser/external_tab_container_win.cc8
-rw-r--r--chrome/browser/external_tab_container_win.h8
-rw-r--r--chrome/browser/first_run/first_run_win.cc6
-rw-r--r--chrome/browser/renderer_host/render_widget_host_view_win.cc2
-rw-r--r--chrome/browser/themes/browser_theme_provider.cc4
-rw-r--r--chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.cc4
-rw-r--r--chrome/browser/ui/views/autocomplete/autocomplete_popup_win.cc4
-rw-r--r--chrome/browser/ui/views/autocomplete/autocomplete_popup_win.h6
-rw-r--r--chrome/browser/ui/views/browser_bubble_win.cc24
-rw-r--r--chrome/browser/ui/views/collected_cookies_win.cc8
-rw-r--r--chrome/browser/ui/views/constrained_html_delegate_win.cc1
-rw-r--r--chrome/browser/ui/views/constrained_window_win.cc10
-rw-r--r--chrome/browser/ui/views/download_started_animation_win.cc6
-rw-r--r--chrome/browser/ui/views/dropdown_bar_host_win.cc6
-rw-r--r--chrome/browser/ui/views/find_bar_host_win.cc4
-rw-r--r--chrome/browser/ui/views/first_run_bubble.cc4
-rw-r--r--chrome/browser/ui/views/frame/browser_frame_win.cc6
-rw-r--r--chrome/browser/ui/views/fullscreen_exit_bubble.cc9
-rw-r--r--chrome/browser/ui/views/generic_info_view_unittest.cc6
-rw-r--r--chrome/browser/ui/views/info_bubble.cc6
-rw-r--r--chrome/browser/ui/views/info_bubble.h12
-rw-r--r--chrome/browser/ui/views/notifications/balloon_view.cc9
-rw-r--r--chrome/browser/ui/views/notifications/balloon_view_host.cc6
-rw-r--r--chrome/browser/ui/views/tab_contents/tab_contents_view_win.cc12
-rw-r--r--chrome/browser/ui/views/tab_contents/tab_contents_view_win.h8
-rw-r--r--chrome/browser/ui/views/tabs/base_tab_strip.cc4
-rw-r--r--chrome/browser/ui/views/tabs/dragged_tab_controller.cc8
-rw-r--r--chrome/browser/ui/views/tabs/dragged_tab_view.cc4
-rw-r--r--chrome/browser/ui/views/tabs/dragged_tab_view.h4
-rw-r--r--chrome/browser/ui/views/tabs/native_view_photobooth_win.cc4
-rw-r--r--chrome/browser/ui/views/tabs/native_view_photobooth_win.h4
-rw-r--r--chrome/browser/ui/views/tabs/tab_strip.cc4
-rw-r--r--chrome/browser/ui/views/tabs/tab_strip.h4
36 files changed, 117 insertions, 104 deletions
diff --git a/chrome/browser/accessibility/browser_views_accessibility_browsertest.cc b/chrome/browser/accessibility/browser_views_accessibility_browsertest.cc
index e03e22e..85f59a3 100644
--- a/chrome/browser/accessibility/browser_views_accessibility_browsertest.cc
+++ b/chrome/browser/accessibility/browser_views_accessibility_browsertest.cc
@@ -20,6 +20,7 @@
#include "ui/base/l10n/l10n_util.h"
#include "views/accessibility/view_accessibility.h"
#include "views/widget/root_view.h"
+#include "views/widget/widget_win.h"
#include "views/window/window.h"
namespace {
diff --git a/chrome/browser/aeropeek_manager.cc b/chrome/browser/aeropeek_manager.cc
index ce96082..b42a359 100644
--- a/chrome/browser/aeropeek_manager.cc
+++ b/chrome/browser/aeropeek_manager.cc
@@ -36,7 +36,7 @@
#include "ui/base/win/window_impl.h"
#include "ui/gfx/gdi_util.h"
#include "ui/gfx/icon_util.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
namespace {
@@ -1016,7 +1016,7 @@ bool AeroPeekManager::Enabled() {
// flooding users with tab thumbnails.
const CommandLine* command_line = CommandLine::ForCurrentProcess();
return base::win::GetVersion() >= base::win::VERSION_WIN7 &&
- views::NativeWidgetWin::IsAeroGlassEnabled() &&
+ views::WidgetWin::IsAeroGlassEnabled() &&
!command_line->HasSwitch(switches::kApp) &&
command_line->HasSwitch(switches::kEnableAeroPeekTabs);
}
diff --git a/chrome/browser/automation/automation_provider_win.cc b/chrome/browser/automation/automation_provider_win.cc
index 64aacc6..e0f76c9 100644
--- a/chrome/browser/automation/automation_provider_win.cc
+++ b/chrome/browser/automation/automation_provider_win.cc
@@ -26,6 +26,7 @@
#include "ui/base/keycodes/keyboard_codes.h"
#include "views/focus/accelerator_handler.h"
#include "views/widget/root_view.h"
+#include "views/widget/widget_win.h"
#include "views/window/window.h"
// This task just adds another task to the event queue. This is useful if
diff --git a/chrome/browser/first_run/first_run_win.cc b/chrome/browser/first_run/first_run_win.cc
index 8bd302f..4f3fe85 100644
--- a/chrome/browser/first_run/first_run_win.cc
+++ b/chrome/browser/first_run/first_run_win.cc
@@ -52,8 +52,8 @@
#include "views/focus/accelerator_handler.h"
#include "views/layout/grid_layout.h"
#include "views/layout/layout_constants.h"
-#include "views/widget/native_widget_win.h"
#include "views/widget/root_view.h"
+#include "views/widget/widget_win.h"
#include "views/window/window.h"
#include "ui/base/resource/resource_bundle.h"
#include "ui/base/l10n/l10n_util.h"
@@ -631,7 +631,7 @@ class TryChromeDialog : public views::ButtonListener,
// An approximate window size. After Layout() we'll get better bounds.
gfx::Rect pos(310, 160);
- views::NativeWidgetWin* popup = new views::NativeWidgetWin;
+ views::WidgetWin* popup = new views::WidgetWin();
if (!popup) {
NOTREACHED();
return Upgrade::TD_DIALOG_ERROR;
@@ -848,7 +848,7 @@ class TryChromeDialog : public views::ButtonListener,
// We don't own any of this pointers. The |popup_| owns itself and owns
// the other views.
- views::NativeWidgetWin* popup_;
+ views::WidgetWin* popup_;
views::RadioButton* try_chrome_;
views::RadioButton* kill_chrome_;
Upgrade::TryResult result_;
diff --git a/chrome/browser/renderer_host/render_widget_host_view_win.cc b/chrome/browser/renderer_host/render_widget_host_view_win.cc
index 8021bcd..896862b 100644
--- a/chrome/browser/renderer_host/render_widget_host_view_win.cc
+++ b/chrome/browser/renderer_host/render_widget_host_view_win.cc
@@ -46,7 +46,7 @@
#include "views/focus/focus_manager.h"
#include "views/focus/focus_util_win.h"
// Included for views::kReflectedMessage - TODO(beng): move this to win_util.h!
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#include "webkit/glue/webaccessibility.h"
#include "webkit/glue/webcursor.h"
#include "webkit/plugins/npapi/plugin_constants_win.h"
diff --git a/chrome/browser/themes/browser_theme_provider.cc b/chrome/browser/themes/browser_theme_provider.cc
index 19599a4..87a73aa 100644
--- a/chrome/browser/themes/browser_theme_provider.cc
+++ b/chrome/browser/themes/browser_theme_provider.cc
@@ -20,7 +20,7 @@
#include "ui/base/resource/resource_bundle.h"
#if defined(OS_WIN)
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#endif
// Strings used in alignment properties.
@@ -255,7 +255,7 @@ bool BrowserThemeProvider::ShouldUseNativeFrame() const {
if (HasCustomImage(IDR_THEME_FRAME))
return false;
#if defined(OS_WIN)
- return views::NativeWidgetWin::IsAeroGlassEnabled();
+ return views::WidgetWin::IsAeroGlassEnabled();
#else
return false;
#endif
diff --git a/chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.cc b/chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.cc
index 246019d..e507df5 100644
--- a/chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.cc
+++ b/chrome/browser/ui/views/autocomplete/autocomplete_popup_contents_view.cc
@@ -43,7 +43,7 @@
#include <objidl.h>
#include "base/win/scoped_gdi_object.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#endif
#if defined(OS_LINUX)
@@ -1103,7 +1103,7 @@ void AutocompletePopupContentsView::MakeContentsPath(
void AutocompletePopupContentsView::UpdateBlurRegion() {
#if defined(OS_WIN)
// We only support background blurring on Vista with Aero-Glass enabled.
- if (!views::NativeWidgetWin::IsAeroGlassEnabled() || !GetWidget())
+ if (!views::WidgetWin::IsAeroGlassEnabled() || !GetWidget())
return;
// Provide a blurred background effect within the contents region of the
diff --git a/chrome/browser/ui/views/autocomplete/autocomplete_popup_win.cc b/chrome/browser/ui/views/autocomplete/autocomplete_popup_win.cc
index 696fc8e..da76989 100644
--- a/chrome/browser/ui/views/autocomplete/autocomplete_popup_win.cc
+++ b/chrome/browser/ui/views/autocomplete/autocomplete_popup_win.cc
@@ -18,8 +18,8 @@ AutocompletePopupWin::AutocompletePopupWin(
// Create the popup.
set_window_style(WS_POPUP | WS_CLIPCHILDREN);
set_window_ex_style(WS_EX_TOOLWINDOW | WS_EX_LAYERED);
- NativeWidgetWin::Init(GetAncestor(edit_view->GetNativeView(), GA_ROOT),
- contents->GetPopupBounds());
+ WidgetWin::Init(GetAncestor(edit_view->GetNativeView(), GA_ROOT),
+ contents->GetPopupBounds());
// The contents is owned by the LocationBarView.
contents->set_parent_owned(false);
SetContentsView(contents);
diff --git a/chrome/browser/ui/views/collected_cookies_win.cc b/chrome/browser/ui/views/collected_cookies_win.cc
index 3ba583c..5c7e45e 100644
--- a/chrome/browser/ui/views/collected_cookies_win.cc
+++ b/chrome/browser/ui/views/collected_cookies_win.cc
@@ -22,8 +22,8 @@
#include "views/layout/box_layout.h"
#include "views/layout/grid_layout.h"
#include "views/layout/layout_constants.h"
-#include "views/widget/native_widget_win.h"
#include "views/widget/root_view.h"
+#include "views/widget/widget_win.h"
#include "views/window/window.h"
namespace browser {
@@ -374,9 +374,9 @@ void CollectedCookiesWin::AddContentException(views::TreeView* tree_view,
infobar_->UpdateVisibility(true, setting, origin_node->GetTitle());
gfx::Rect bounds;
GetWidget()->GetBounds(&bounds, false);
- // NativeWidgetWin::GetBounds returns the bounds relative to the parent
- // window, while NativeWidgetWin::SetBounds wants screen coordinates. Do the
- // translation here until http://crbug.com/52851 is fixed.
+ // WidgetWin::GetBounds returns the bounds relative to the parent window,
+ // while WidgetWin::SetBounds wants screen coordinates. Do the translation
+ // here until http://crbug.com/52851 is fixed.
POINT topleft = {bounds.x(), bounds.y()};
MapWindowPoints(HWND_DESKTOP, tab_contents_->GetNativeView(), &topleft, 1);
gfx::Size size = GetRootView()->GetPreferredSize();
diff --git a/chrome/browser/ui/views/constrained_html_delegate_win.cc b/chrome/browser/ui/views/constrained_html_delegate_win.cc
index 177fa93..98fe7666 100644
--- a/chrome/browser/ui/views/constrained_html_delegate_win.cc
+++ b/chrome/browser/ui/views/constrained_html_delegate_win.cc
@@ -12,6 +12,7 @@
#include "ipc/ipc_message.h"
#include "ui/gfx/rect.h"
#include "views/view.h"
+#include "views/widget/widget_win.h"
#include "views/window/window_delegate.h"
class ConstrainedHtmlDelegateWin : public TabContentsContainer,
diff --git a/chrome/browser/ui/views/download_started_animation_win.cc b/chrome/browser/ui/views/download_started_animation_win.cc
index 625ca24..973eca2 100644
--- a/chrome/browser/ui/views/download_started_animation_win.cc
+++ b/chrome/browser/ui/views/download_started_animation_win.cc
@@ -13,7 +13,7 @@
#include "ui/base/resource/resource_bundle.h"
#include "ui/gfx/rect.h"
#include "views/controls/image_view.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
// How long to spend moving downwards and fading out after waiting.
static const int kMoveTimeMs = 600;
@@ -55,7 +55,7 @@ class DownloadStartedAnimationWin : public ui::LinearAnimation,
const NotificationDetails& details);
// We use a HWND for the popup so that it may float above any HWNDs in our UI.
- views::NativeWidgetWin* popup_;
+ views::WidgetWin* popup_;
// The content area holding us.
TabContents* tab_contents_;
@@ -102,7 +102,7 @@ DownloadStartedAnimationWin::DownloadStartedAnimationWin(
SetImage(kDownloadImage);
gfx::Rect rc(0, 0, 0, 0);
- popup_ = new views::NativeWidgetWin;
+ popup_ = new views::WidgetWin;
popup_->set_window_style(WS_POPUP);
popup_->set_window_ex_style(WS_EX_LAYERED | WS_EX_TOOLWINDOW |
WS_EX_TRANSPARENT);
diff --git a/chrome/browser/ui/views/find_bar_host_win.cc b/chrome/browser/ui/views/find_bar_host_win.cc
index 83dbe4a..ee0a980 100644
--- a/chrome/browser/ui/views/find_bar_host_win.cc
+++ b/chrome/browser/ui/views/find_bar_host_win.cc
@@ -11,7 +11,7 @@
#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
#include "chrome/browser/ui/views/frame/browser_view.h"
#include "views/controls/scrollbar/native_scroll_bar.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
void FindBarHost::AudibleAlert() {
MessageBeep(MB_OK);
@@ -20,7 +20,7 @@ void FindBarHost::AudibleAlert() {
void FindBarHost::GetWidgetPositionNative(gfx::Rect* avoid_overlapping_rect) {
RECT frame_rect = {0}, webcontents_rect = {0};
::GetWindowRect(
- static_cast<views::NativeWidgetWin*>(host())->GetParent(), &frame_rect);
+ static_cast<views::WidgetWin*>(host())->GetParent(), &frame_rect);
::GetWindowRect(
find_bar_controller_->
tab_contents()->tab_contents()->view()->GetNativeView(),
diff --git a/chrome/browser/ui/views/first_run_bubble.cc b/chrome/browser/ui/views/first_run_bubble.cc
index 31dd3b8..802979a 100644
--- a/chrome/browser/ui/views/first_run_bubble.cc
+++ b/chrome/browser/ui/views/first_run_bubble.cc
@@ -24,7 +24,7 @@
#include "views/events/event.h"
#include "views/focus/focus_manager.h"
#include "views/layout/layout_constants.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#include "views/window/window.h"
namespace {
@@ -359,7 +359,7 @@ gfx::Size FirstRunOEMBubbleView::GetPreferredSize() {
// now, we force Vista to show a correctly-sized box by taking account of
// the difference in font size calculation. The coefficient should not be
// stored in a variable because it's a hack and should go away.
- if (views::NativeWidgetWin::IsAeroGlassEnabled()) {
+ if (views::WidgetWin::IsAeroGlassEnabled()) {
size.set_width(static_cast<int>(size.width() * 0.85));
size.set_height(static_cast<int>(size.height() * 0.85));
}
diff --git a/chrome/browser/ui/views/frame/browser_frame_win.cc b/chrome/browser/ui/views/frame/browser_frame_win.cc
index e7fa6853..1db3f49 100644
--- a/chrome/browser/ui/views/frame/browser_frame_win.cc
+++ b/chrome/browser/ui/views/frame/browser_frame_win.cc
@@ -20,7 +20,7 @@
#include "grit/theme_resources.h"
#include "ui/gfx/font.h"
#include "views/screen.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#include "views/window/window_delegate.h"
#include "views/window/window_win.h"
@@ -111,7 +111,7 @@ bool BrowserFrameWin::AlwaysUseNativeFrame() const {
// theme is active for normal browser windows, we don't want to use the custom
// frame for popups/apps.
if (!browser_view_->IsBrowserTypeNormal() &&
- views::NativeWidgetWin::IsAeroGlassEnabled())
+ views::WidgetWin::IsAeroGlassEnabled())
return true;
// Otherwise, we use the native frame when we're told we should by the theme
@@ -168,7 +168,7 @@ void BrowserFrameWin::OnEnterSizeMove() {
}
void BrowserFrameWin::OnExitSizeMove() {
- views::NativeWidgetWin::OnExitSizeMove();
+ views::WidgetWin::OnExitSizeMove();
}
void BrowserFrameWin::OnInitMenuPopup(HMENU menu, UINT position,
diff --git a/chrome/browser/ui/views/fullscreen_exit_bubble.cc b/chrome/browser/ui/views/fullscreen_exit_bubble.cc
index 418893f..fc38f30 100644
--- a/chrome/browser/ui/views/fullscreen_exit_bubble.cc
+++ b/chrome/browser/ui/views/fullscreen_exit_bubble.cc
@@ -18,7 +18,7 @@
#if defined(OS_WIN)
#include "ui/base/l10n/l10n_util_win.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#elif defined(OS_LINUX)
#include "views/widget/widget_gtk.h"
#endif
@@ -108,13 +108,12 @@ void FullscreenExitBubble::FullscreenExitView::Paint(gfx::Canvas* canvas) {
// FullscreenExitPopup ---------------------------------------------------------
#if defined(OS_WIN)
-class FullscreenExitBubble::FullscreenExitPopup
- : public views::NativeWidgetWin {
+class FullscreenExitBubble::FullscreenExitPopup : public views::WidgetWin {
public:
- FullscreenExitPopup() : views::NativeWidgetWin() {}
+ FullscreenExitPopup() : views::WidgetWin() {}
virtual ~FullscreenExitPopup() {}
- // views::NativeWidgetWin:
+ // views::WidgetWin:
virtual LRESULT OnMouseActivate(HWND window,
UINT hittest_code,
UINT message) {
diff --git a/chrome/browser/ui/views/generic_info_view_unittest.cc b/chrome/browser/ui/views/generic_info_view_unittest.cc
index 29393f3..8f7cceb 100644
--- a/chrome/browser/ui/views/generic_info_view_unittest.cc
+++ b/chrome/browser/ui/views/generic_info_view_unittest.cc
@@ -14,7 +14,7 @@
#include "views/window/window.h"
#if defined(OS_WIN)
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#endif
// This class is only used on windows for now.
@@ -25,7 +25,7 @@ using namespace views;
class GenericInfoViewTest : public testing::Test {
public:
Widget* CreateWidget() {
- return new NativeWidgetWin;
+ return new WidgetWin();
}
private:
MessageLoopForUI message_loop_;
@@ -36,7 +36,7 @@ TEST_F(GenericInfoViewTest, GenericInfoView) {
const string16 kValue = ASCIIToUTF16("Value");
Widget* window = CreateWidget();
- static_cast<NativeWidgetWin*>(window)->Init(NULL, gfx::Rect(0, 0, 100, 100));
+ static_cast<WidgetWin*>(window)->Init(NULL, gfx::Rect(0, 0, 100, 100));
RootView* root_view = window->GetRootView();
GenericInfoView* view1 = new GenericInfoView(1);
diff --git a/chrome/browser/ui/views/info_bubble.cc b/chrome/browser/ui/views/info_bubble.cc
index a6fdce4..aad0b38 100644
--- a/chrome/browser/ui/views/info_bubble.cc
+++ b/chrome/browser/ui/views/info_bubble.cc
@@ -208,7 +208,7 @@ void BorderWidget::Init(BorderContents* border_contents, HWND owner) {
DCHECK(!border_contents_);
border_contents_ = border_contents;
border_contents_->Init();
- NativeWidgetWin::Init(owner, gfx::Rect());
+ WidgetWin::Init(owner, gfx::Rect());
SetContentsView(border_contents_);
SetWindowPos(owner, 0, 0, 0, 0,
SWP_NOSIZE | SWP_NOMOVE | SWP_NOACTIVATE | SWP_NOREDRAW);
@@ -383,7 +383,7 @@ void InfoBubble::Init(views::Widget* parent,
// We make the BorderWidget the owner of the InfoBubble HWND, so that the
// latter is displayed on top of the former.
- NativeWidgetWin::Init(border_->GetNativeView(), gfx::Rect());
+ WidgetWin::Init(border_->GetNativeView(), gfx::Rect());
SetWindowText(GetNativeView(), delegate_->accessible_name().c_str());
#elif defined(OS_LINUX)
@@ -522,7 +522,7 @@ void InfoBubble::DoClose(bool closed_by_escape) {
show_status_ = kClosed;
#if defined(OS_WIN)
border_->Close();
- NativeWidgetWin::Close();
+ WidgetWin::Close();
#elif defined(OS_LINUX)
WidgetGtk::Close();
#endif
diff --git a/chrome/browser/ui/views/notifications/balloon_view.cc b/chrome/browser/ui/views/notifications/balloon_view.cc
index 33cec57..69859cb 100644
--- a/chrome/browser/ui/views/notifications/balloon_view.cc
+++ b/chrome/browser/ui/views/notifications/balloon_view.cc
@@ -36,7 +36,12 @@
#include "views/controls/native/native_view_host.h"
#include "views/painter.h"
#include "views/widget/root_view.h"
-#include "views/widget/widget.h"
+#if defined(OS_WIN)
+#include "views/widget/widget_win.h"
+#endif
+#if defined(OS_LINUX)
+#include "views/widget/widget_gtk.h"
+#endif
using views::Widget;
@@ -94,7 +99,7 @@ BalloonViewImpl::BalloonViewImpl(BalloonCollection* collection)
frame_container_(NULL),
html_container_(NULL),
html_contents_(NULL),
- ALLOW_THIS_IN_INITIALIZER_LIST(method_factory_(this)),
+ method_factory_(this),
close_button_(NULL),
animation_(NULL),
options_menu_model_(NULL),
diff --git a/chrome/browser/ui/views/notifications/balloon_view_host.cc b/chrome/browser/ui/views/notifications/balloon_view_host.cc
index 869a8b4..fcdbadf 100644
--- a/chrome/browser/ui/views/notifications/balloon_view_host.cc
+++ b/chrome/browser/ui/views/notifications/balloon_view_host.cc
@@ -18,6 +18,12 @@
#endif
#endif
#include "views/widget/widget.h"
+#if defined(OS_WIN)
+#include "views/widget/widget_win.h"
+#endif
+#if defined(OS_LINUX)
+#include "views/widget/widget_gtk.h"
+#endif
class BalloonViewHostView : public views::NativeViewHost {
public:
diff --git a/chrome/browser/ui/views/tab_contents/tab_contents_view_win.cc b/chrome/browser/ui/views/tab_contents/tab_contents_view_win.cc
index 870777b..6a5bb7e 100644
--- a/chrome/browser/ui/views/tab_contents/tab_contents_view_win.cc
+++ b/chrome/browser/ui/views/tab_contents/tab_contents_view_win.cc
@@ -58,7 +58,7 @@ TabContentsViewWin::~TabContentsViewWin() {
void TabContentsViewWin::Unparent() {
// Remember who our FocusManager is, we won't be able to access it once
// unparented.
- focus_manager_ = views::NativeWidgetWin::GetFocusManager();
+ focus_manager_ = views::WidgetWin::GetFocusManager();
// Note that we do not DCHECK on focus_manager_ as it may be NULL when used
// with an external tab container.
::SetParent(GetNativeView(), NULL);
@@ -69,7 +69,7 @@ void TabContentsViewWin::CreateView(const gfx::Size& initial_size) {
// Since we create these windows parented to the desktop window initially, we
// don't want to create them initially visible.
set_window_style(WS_CHILD | WS_CLIPCHILDREN | WS_CLIPSIBLINGS);
- NativeWidgetWin::Init(GetDesktopWindow(), gfx::Rect());
+ WidgetWin::Init(GetDesktopWindow(), gfx::Rect());
// Remove the root view drop target so we can register our own.
RevokeDragDrop(GetNativeView());
@@ -102,7 +102,7 @@ RenderWidgetHostView* TabContentsViewWin::CreateViewForWidget(
}
gfx::NativeView TabContentsViewWin::GetNativeView() const {
- return NativeWidgetWin::GetNativeView();
+ return WidgetWin::GetNativeView();
}
gfx::NativeView TabContentsViewWin::GetContentNativeView() const {
@@ -144,7 +144,7 @@ void TabContentsViewWin::OnDestroy() {
drop_target_ = NULL;
}
- NativeWidgetWin::OnDestroy();
+ WidgetWin::OnDestroy();
}
void TabContentsViewWin::SetPageTitle(const std::wstring& title) {
@@ -307,7 +307,7 @@ void TabContentsViewWin::TakeFocus(bool reverse) {
}
views::FocusManager* TabContentsViewWin::GetFocusManager() {
- views::FocusManager* focus_manager = NativeWidgetWin::GetFocusManager();
+ views::FocusManager* focus_manager = WidgetWin::GetFocusManager();
if (focus_manager) {
// If focus_manager_ is non NULL, it means we have been reparented, in which
// case its value may not be valid anymore.
@@ -372,7 +372,7 @@ void TabContentsViewWin::OnMouseLeave() {
LRESULT TabContentsViewWin::OnMouseRange(UINT msg,
WPARAM w_param, LPARAM l_param) {
if (tab_contents()->is_crashed() && sad_tab_ != NULL) {
- return NativeWidgetWin::OnMouseRange(msg, w_param, l_param);
+ return WidgetWin::OnMouseRange(msg, w_param, l_param);
}
switch (msg) {
diff --git a/chrome/browser/ui/views/tabs/base_tab_strip.cc b/chrome/browser/ui/views/tabs/base_tab_strip.cc
index 1a9ecff..1afbc1b 100644
--- a/chrome/browser/ui/views/tabs/base_tab_strip.cc
+++ b/chrome/browser/ui/views/tabs/base_tab_strip.cc
@@ -12,7 +12,7 @@
#include "views/window/window.h"
#if defined(OS_WIN)
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#endif
namespace {
@@ -99,7 +99,7 @@ class BaseTabStrip::RemoveTabDelegate
POINT cursor_point = {GET_X_LPARAM(pos), GET_Y_LPARAM(pos)};
MapWindowPoints(NULL, widget->GetNativeView(), &cursor_point, 1);
- static_cast<views::NativeWidgetWin*>(widget)->ResetLastMouseMoveFlag();
+ static_cast<views::WidgetWin*>(widget)->ResetLastMouseMoveFlag();
// Return to message loop - otherwise we may disrupt some operation that's
// in progress.
SendMessage(widget->GetNativeView(), WM_MOUSEMOVE, 0,
diff --git a/chrome/browser/ui/views/tabs/dragged_tab_controller.cc b/chrome/browser/ui/views/tabs/dragged_tab_controller.cc
index 88d0ee3..0ee3832 100644
--- a/chrome/browser/ui/views/tabs/dragged_tab_controller.cc
+++ b/chrome/browser/ui/views/tabs/dragged_tab_controller.cc
@@ -40,7 +40,7 @@
#include "views/window/window.h"
#if defined(OS_WIN)
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#endif
#if defined(OS_LINUX)
@@ -211,7 +211,7 @@ class DraggedTabController::DockDisplayer : public ui::AnimationDelegate {
hidden_(false),
in_enable_area_(info.in_enable_area()) {
#if defined(OS_WIN)
- views::NativeWidgetWin* popup = new views::NativeWidgetWin;
+ views::WidgetWin* popup = new views::WidgetWin;
popup_ = popup;
popup->set_window_style(WS_POPUP);
popup->set_window_ex_style(WS_EX_LAYERED | WS_EX_TOOLWINDOW |
@@ -274,7 +274,7 @@ class DraggedTabController::DockDisplayer : public ui::AnimationDelegate {
if (!hidden_)
return;
#if defined(OS_WIN)
- static_cast<views::NativeWidgetWin*>(popup_)->Close();
+ static_cast<views::WidgetWin*>(popup_)->Close();
#else
NOTIMPLEMENTED();
#endif
@@ -284,7 +284,7 @@ class DraggedTabController::DockDisplayer : public ui::AnimationDelegate {
virtual void UpdateLayeredAlpha() {
#if defined(OS_WIN)
double scale = in_enable_area_ ? 1 : .5;
- static_cast<views::NativeWidgetWin*>(popup_)->SetOpacity(
+ static_cast<views::WidgetWin*>(popup_)->SetOpacity(
static_cast<BYTE>(animation_.GetCurrentValue() * scale * 255.0));
popup_->GetRootView()->SchedulePaint();
#else
diff --git a/chrome/browser/ui/views/tabs/dragged_tab_view.cc b/chrome/browser/ui/views/tabs/dragged_tab_view.cc
index a5e3706..367019e 100644
--- a/chrome/browser/ui/views/tabs/dragged_tab_view.cc
+++ b/chrome/browser/ui/views/tabs/dragged_tab_view.cc
@@ -10,7 +10,7 @@
#include "views/widget/widget.h"
#if defined(OS_WIN)
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#elif defined(OS_LINUX)
#include "views/widget/widget_gtk.h"
#endif
@@ -38,7 +38,7 @@ DraggedTabView::DraggedTabView(views::View* renderer,
set_parent_owned(false);
#if defined(OS_WIN)
- container_.reset(new views::NativeWidgetWin);
+ container_.reset(new views::WidgetWin);
container_->set_delete_on_destroy(false);
container_->set_window_style(WS_POPUP);
container_->set_window_ex_style(
diff --git a/chrome/browser/ui/views/tabs/dragged_tab_view.h b/chrome/browser/ui/views/tabs/dragged_tab_view.h
index f772efe..d2dda61 100644
--- a/chrome/browser/ui/views/tabs/dragged_tab_view.h
+++ b/chrome/browser/ui/views/tabs/dragged_tab_view.h
@@ -13,7 +13,7 @@
namespace views {
#if defined(OS_WIN)
-class NativeWidgetWin;
+class WidgetWin;
#elif defined(OS_LINUX)
class WidgetGtk;
#endif
@@ -70,7 +70,7 @@ class DraggedTabView : public views::View {
// The window that contains the DraggedTabView.
#if defined(OS_WIN)
- scoped_ptr<views::NativeWidgetWin> container_;
+ scoped_ptr<views::WidgetWin> container_;
#elif defined(OS_LINUX)
scoped_ptr<views::WidgetGtk> container_;
#endif
diff --git a/chrome/browser/ui/views/tabs/native_view_photobooth_win.cc b/chrome/browser/ui/views/tabs/native_view_photobooth_win.cc
index 96f5dc0..0a912fb 100644
--- a/chrome/browser/ui/views/tabs/native_view_photobooth_win.cc
+++ b/chrome/browser/ui/views/tabs/native_view_photobooth_win.cc
@@ -8,7 +8,7 @@
#include "third_party/skia/include/core/SkBitmap.h"
#include "ui/gfx/canvas_skia.h"
#include "ui/gfx/point.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
namespace {
@@ -149,7 +149,7 @@ void NativeViewPhotoboothWin::CreateCaptureWindow(HWND initial_hwnd) {
gfx::Point window_position = GetCaptureWindowPosition();
gfx::Rect capture_bounds(window_position.x(), window_position.y(),
contents_rect.Width(), contents_rect.Height());
- capture_window_ = new views::NativeWidgetWin;
+ capture_window_ = new views::WidgetWin;
capture_window_->set_window_style(WS_POPUP);
// WS_EX_TOOLWINDOW ensures the capture window doesn't produce a Taskbar
// button.
diff --git a/chrome/browser/ui/views/tabs/native_view_photobooth_win.h b/chrome/browser/ui/views/tabs/native_view_photobooth_win.h
index 16e03fd..44402ae 100644
--- a/chrome/browser/ui/views/tabs/native_view_photobooth_win.h
+++ b/chrome/browser/ui/views/tabs/native_view_photobooth_win.h
@@ -9,7 +9,7 @@
#include "chrome/browser/ui/views/tabs/native_view_photobooth.h"
namespace views {
-class NativeWidgetWin;
+class WidgetWin;
}
///////////////////////////////////////////////////////////////////////////////
@@ -47,7 +47,7 @@ class NativeViewPhotoboothWin : public NativeViewPhotobooth {
void CreateCaptureWindow(HWND initial_hwnd);
// The nearly off-screen photo-booth layered window used to hold the HWND.
- views::NativeWidgetWin* capture_window_;
+ views::WidgetWin* capture_window_;
// The current HWND being captured.
HWND current_hwnd_;
diff --git a/chrome/browser/ui/views/tabs/tab_strip.cc b/chrome/browser/ui/views/tabs/tab_strip.cc
index e81f2f6..84d7517 100644
--- a/chrome/browser/ui/views/tabs/tab_strip.cc
+++ b/chrome/browser/ui/views/tabs/tab_strip.cc
@@ -30,7 +30,7 @@
#if defined(OS_WIN)
#include "views/widget/monitor_win.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#elif defined(OS_LINUX)
#include "views/widget/widget_gtk.h"
#endif
@@ -782,7 +782,7 @@ TabStrip::DropInfo::DropInfo(int drop_index, bool drop_before, bool point_down)
arrow_view->SetImage(GetDropArrowImage(point_down));
#if defined(OS_WIN)
- arrow_window = new views::NativeWidgetWin;
+ arrow_window = new views::WidgetWin;
arrow_window->set_window_style(WS_POPUP);
arrow_window->set_window_ex_style(WS_EX_TOPMOST | WS_EX_NOACTIVATE |
WS_EX_LAYERED | WS_EX_TRANSPARENT);
diff --git a/chrome/browser/ui/views/tabs/tab_strip.h b/chrome/browser/ui/views/tabs/tab_strip.h
index 67e3d00..82f3f35 100644
--- a/chrome/browser/ui/views/tabs/tab_strip.h
+++ b/chrome/browser/ui/views/tabs/tab_strip.h
@@ -22,7 +22,7 @@ class ImageView;
#if defined(OS_LINUX)
class WidgetGtk;
#elif defined(OS_WIN)
-class NativeWidgetWin;
+class WidgetWin;
#endif
}
@@ -126,7 +126,7 @@ class TabStrip : public BaseTabStrip,
// Renders the drop indicator.
// TODO(beng): should be views::Widget.
#if defined(OS_WIN)
- views::NativeWidgetWin* arrow_window;
+ views::WidgetWin* arrow_window;
#else
views::WidgetGtk* arrow_window;
#endif
diff --git a/chrome/browser/external_tab_container_win.cc b/chrome/browser/external_tab_container_win.cc
index 499bde3..d5f7a7c 100644
--- a/chrome/browser/external_tab_container_win.cc
+++ b/chrome/browser/external_tab_container_win.cc
@@ -134,7 +134,7 @@ bool ExternalTabContainer::Init(Profile* profile,
route_all_top_level_navigations_ = route_all_top_level_navigations;
set_window_style(WS_POPUP | WS_CLIPCHILDREN);
- views::NativeWidgetWin::Init(NULL, bounds);
+ views::WidgetWin::Init(NULL, bounds);
if (!IsWindow()) {
NOTREACHED();
return false;
@@ -798,10 +798,10 @@ void ExternalTabContainer::Observe(NotificationType type,
}
////////////////////////////////////////////////////////////////////////////////
// ExternalTabContainer, views::NativeWidgetWin overrides:
LRESULT ExternalTabContainer::OnCreate(LPCREATESTRUCT create_struct) {
- LRESULT result = views::NativeWidgetWin::OnCreate(create_struct);
+ LRESULT result = views::WidgetWin::OnCreate(create_struct);
if (result == 0) {
// Grab a reference here which will be released in OnFinalMessage
AddRef();
@@ -812,7 +812,7 @@ LRESULT ExternalTabContainer::OnCreate(LPCREATESTRUCT create_struct) {
void ExternalTabContainer::OnDestroy() {
prop_.reset();
Uninitialize();
- NativeWidgetWin::OnDestroy();
+ WidgetWin::OnDestroy();
if (browser_.get()) {
::DestroyWindow(browser_->window()->GetNativeHandle());
}
@@ -798,10 +798,10 @@ void ExternalTabContainer::Observe(NotificationType type,
}
////////////////////////////////////////////////////////////////////////////////
-// ExternalTabContainer, views::NativeWidgetWin overrides:
+// ExternalTabContainer, views::WidgetWin overrides:
LRESULT ExternalTabContainer::OnCreate(LPCREATESTRUCT create_struct) {
diff --git a/chrome/browser/external_tab_container_win.h b/chrome/browser/external_tab_container_win.h
index e8b0e2b..63a5958 100644
--- a/chrome/browser/external_tab_container_win.h
+++ b/chrome/browser/external_tab_container_win.h
@@ -22,7 +22,7 @@
#include "chrome/common/notification_observer.h"
#include "chrome/common/notification_registrar.h"
#include "views/accelerator.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
class AutomationProvider;
class Browser;
@@ -42,7 +42,7 @@ class ViewProp;
// TabContents as well as an implementation of TabContentsDelegate.
class ExternalTabContainer : public TabContentsDelegate,
public NotificationObserver,
- public views::NativeWidgetWin,
+ public views::WidgetWin,
public base::RefCounted<ExternalTabContainer>,
public views::AcceleratorTarget,
public InfoBarContainer::Delegate,
@@ -192,7 +192,7 @@ class ExternalTabContainer : public TabContentsDelegate,
void SetEnableExtensionAutomation(
const std::vector<std::string>& functions_enabled);
// Overridden from views::NativeWidgetWin:
virtual views::Window* GetWindow();
// Handles the specified |accelerator| being pressed.
@@ -217,7 +217,7 @@ class ExternalTabContainer : public TabContentsDelegate,
protected:
~ExternalTabContainer();
// Overridden from views::NativeWidgetWin:
virtual LRESULT OnCreate(LPCREATESTRUCT create_struct);
virtual void OnDestroy();
virtual void OnFinalMessage(HWND window);
@@ -192,7 +192,7 @@ class ExternalTabContainer : public TabContentsDelegate,
void SetEnableExtensionAutomation(
const std::vector<std::string>& functions_enabled);
- // Overridden from views::NativeWidgetWin:
+ // Overridden from views::WidgetWin:
virtual views::Window* GetWindow();
// Handles the specified |accelerator| being pressed.
@@ -217,7 +217,7 @@ class ExternalTabContainer : public TabContentsDelegate,
protected:
~ExternalTabContainer();
- // Overridden from views::NativeWidgetWin:
+ // Overridden from views::WidgetWin:
virtual LRESULT OnCreate(LPCREATESTRUCT create_struct);
virtual void OnDestroy();
diff --git a/chrome/browser/ui/views/autocomplete/autocomplete_popup_win.h b/chrome/browser/ui/views/autocomplete/autocomplete_popup_win.h
index 58732b8..bcb7af4 100644
--- a/chrome/browser/ui/views/autocomplete/autocomplete_popup_win.h
+++ b/chrome/browser/ui/views/autocomplete/autocomplete_popup_win.h
@@ -7,13 +7,13 @@
#pragma once
#include "base/weak_ptr.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
class AutocompleteEditView;
class AutocompletePopupContentsView;
class AutocompletePopupWin
- : public views::NativeWidgetWin,
+ : public views::WidgetWin,
public base::SupportsWeakPtr<AutocompletePopupWin> {
public:
// Creates the popup and shows it. |edit_view| is the edit that created us.
@@ -22,7 +22,7 @@ class AutocompletePopupWin
virtual ~AutocompletePopupWin();
private:
// Overridden from NativeWidgetWin:
virtual LRESULT OnMouseActivate(HWND window,
UINT hit_test,
UINT mouse_message);
@@ -22,7 +22,7 @@ class AutocompletePopupWin
virtual ~AutocompletePopupWin();
private:
- // Overridden from NativeWidgetWin:
+ // Overridden from WidgetWin:
virtual LRESULT OnMouseActivate(HWND window,
UINT hit_test,
diff --git a/chrome/browser/ui/views/browser_bubble_win.cc b/chrome/browser/ui/views/browser_bubble_win.cc
index 6f1d8dc..4d75cdf 100644
--- a/chrome/browser/ui/views/browser_bubble_win.cc
+++ b/chrome/browser/ui/views/browser_bubble_win.cc
@@ -5,11 +5,11 @@
#include "chrome/browser/ui/views/browser_bubble.h"
#include "chrome/browser/ui/views/frame/browser_view.h"
-#include "views/widget/native_widget_win.h"
#include "views/widget/root_view.h"
+#include "views/widget/widget_win.h"
#include "views/window/window.h"
-class BubbleWidget : public views::NativeWidgetWin {
+class BubbleWidget : public views::WidgetWin {
public:
explicit BubbleWidget(BrowserBubble* bubble)
: bubble_(bubble) {
@@ -21,7 +21,7 @@ class BubbleWidget : public views::NativeWidgetWin {
if (activate)
ShowWindow(SW_SHOW);
else
- views::NativeWidgetWin::Show();
+ views::WidgetWin::Show();
}
void Close() {
@@ -32,7 +32,7 @@ class BubbleWidget : public views::NativeWidgetWin {
if (delegate)
delegate->BubbleLostFocus(bubble_, NULL);
}
- views::NativeWidgetWin::Close();
+ views::WidgetWin::Close();
bubble_ = NULL;
}
@@ -42,11 +42,11 @@ class BubbleWidget : public views::NativeWidgetWin {
if (delegate)
delegate->BubbleLostFocus(bubble_, NULL);
}
- views::NativeWidgetWin::Hide();
+ views::WidgetWin::Hide();
}
void OnActivate(UINT action, BOOL minimized, HWND window) {
- NativeWidgetWin::OnActivate(action, minimized, window);
+ WidgetWin::OnActivate(action, minimized, window);
if (!bubble_)
return;
@@ -82,7 +82,7 @@ class BubbleWidget : public views::NativeWidgetWin {
}
virtual void OnSetFocus(HWND focused_window) {
- NativeWidgetWin::OnSetFocus(focused_window);
+ WidgetWin::OnSetFocus(focused_window);
if (bubble_ && bubble_->delegate())
bubble_->delegate()->BubbleGotFocus(bubble_);
}
@@ -94,9 +94,9 @@ class BubbleWidget : public views::NativeWidgetWin {
};
void BrowserBubble::InitPopup() {
- // popup_ is a Widget, but we need to do some NativeWidgetWin stuff first,
- // then we'll assign it into popup_.
- views::NativeWidgetWin* pop = new BubbleWidget(this);
+ // popup_ is a Widget, but we need to do some WidgetWin stuff first, then
+ // we'll assign it into popup_.
+ views::WidgetWin* pop = new BubbleWidget(this);
pop->Init(frame_->GetNativeView(), bounds_);
pop->SetContentsView(view_);
@@ -107,7 +107,7 @@ void BrowserBubble::InitPopup() {
}
void BrowserBubble::MovePopup(int x, int y, int w, int h) {
- views::NativeWidgetWin* pop = static_cast<views::NativeWidgetWin*>(popup_);
+ views::WidgetWin* pop = static_cast<views::WidgetWin*>(popup_);
pop->SetBounds(gfx::Rect(x, y, w, h));
}
@@ -122,7 +122,7 @@ void BrowserBubble::Show(bool activate) {
void BrowserBubble::Hide() {
if (!visible_)
return;
- views::NativeWidgetWin* pop = static_cast<views::NativeWidgetWin*>(popup_);
+ views::WidgetWin* pop = static_cast<views::WidgetWin*>(popup_);
pop->Hide();
visible_ = false;
}
diff --git a/chrome/browser/ui/views/constrained_window_win.cc b/chrome/browser/ui/views/constrained_window_win.cc
index daf4b26..116a072 100644
--- a/chrome/browser/ui/views/constrained_window_win.cc
+++ b/chrome/browser/ui/views/constrained_window_win.cc
@@ -27,7 +27,7 @@
#include "ui/gfx/rect.h"
#include "views/controls/button/image_button.h"
#include "views/focus/focus_manager.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#include "views/window/client_view.h"
#include "views/window/non_client_view.h"
#include "views/window/window_resources.h"
@@ -198,8 +198,8 @@ class ConstrainedWindowFrameView
SkColor GetTitleColor() const {
return (container_->owner()->profile()->IsOffTheRecord() ||
- !views::NativeWidgetWin::IsAeroGlassEnabled()) ? SK_ColorWHITE
- : SK_ColorBLACK;
+ !views::WidgetWin::IsAeroGlassEnabled()) ? SK_ColorWHITE
+ : SK_ColorBLACK;
}
// Loads the appropriate set of WindowResources for the frame view.
@@ -536,7 +536,7 @@ gfx::Rect ConstrainedWindowFrameView::CalculateClientAreaBounds(
}
void ConstrainedWindowFrameView::InitWindowResources() {
- resources_.reset(views::NativeWidgetWin::IsAeroGlassEnabled() ?
+ resources_.reset(views::WidgetWin::IsAeroGlassEnabled() ?
static_cast<views::WindowResources*>(new VistaWindowResources) :
new XPWindowResources);
}
@@ -632,7 +632,7 @@ void ConstrainedWindowWin::ActivateConstrainedWindow() {
}
////////////////////////////////////////////////////////////////////////////////
// ConstrainedWindowWin, views::NativeWidgetWin overrides:
void ConstrainedWindowWin::OnDestroy() {
// TODO(jcampan): figure out focus restoration
@@ -632,7 +632,7 @@ void ConstrainedWindowWin::ActivateConstrainedWindow() {
}
////////////////////////////////////////////////////////////////////////////////
-// ConstrainedWindowWin, views::NativeWidgetWin overrides:
+// ConstrainedWindowWin, views::WidgetWin overrides:
void ConstrainedWindowWin::OnDestroy() {
// TODO(jcampan): figure out focus restoration
diff --git a/chrome/browser/ui/views/dropdown_bar_host_win.cc b/chrome/browser/ui/views/dropdown_bar_host_win.cc
index 30fb85f..ef25f14 100644
--- a/chrome/browser/ui/views/dropdown_bar_host_win.cc
+++ b/chrome/browser/ui/views/dropdown_bar_host_win.cc
@@ -11,7 +11,7 @@
#include "chrome/browser/ui/views/frame/browser_view.h"
#include "ui/base/keycodes/keyboard_code_conversion_win.h"
#include "views/controls/scrollbar/native_scroll_bar.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
NativeWebKeyboardEvent DropdownBarHost::GetKeyboardEvent(
const TabContents* contents,
@@ -23,8 +23,8 @@ NativeWebKeyboardEvent DropdownBarHost::GetKeyboardEvent(
}
views::Widget* DropdownBarHost::CreateHost() {
- views::NativeWidgetWin* widget = new views::NativeWidgetWin;
- // Don't let NativeWidgetWin manage our lifetime. We want our lifetime to
+ views::WidgetWin* widget = new views::WidgetWin();
+ // Don't let WidgetWin manage our lifetime. We want our lifetime to
// coincide with TabContents.
widget->set_delete_on_destroy(false);
widget->set_window_style(WS_CHILD | WS_CLIPCHILDREN);
diff --git a/chrome/browser/ui/views/info_bubble.h b/chrome/browser/ui/views/info_bubble.h
index 79a0eec..b329e80 100644
--- a/chrome/browser/ui/views/info_bubble.h
+++ b/chrome/browser/ui/views/info_bubble.h
@@ -13,7 +13,7 @@
#include "views/view.h"
#if defined(OS_WIN)
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
#elif defined(OS_LINUX)
#include "views/widget/widget_gtk.h"
#endif
@@ -117,7 +117,7 @@ class BorderContents : public views::View {
// we can use >1-bit alpha shadow images on the borders, which look nicer than
// the Windows CS_DROPSHADOW shadows. The info bubble window itself cannot be a
// layered window because that prevents it from hosting native child controls.
-class BorderWidget : public views::NativeWidgetWin {
+class BorderWidget : public views::WidgetWin {
public:
BorderWidget();
virtual ~BorderWidget() { }
@@ -142,7 +142,7 @@ class BorderWidget : public views::NativeWidgetWin {
BorderContents* border_contents_;
private:
// Overridden from NativeWidgetWin:
virtual LRESULT OnMouseActivate(HWND window,
UINT hit_test,
UINT mouse_message);
@@ -179,7 +179,7 @@ class InfoBubbleDelegate {
// That way InfoBubble has no (or very few) ifdefs.
class InfoBubble
#if defined(OS_WIN)
- : public views::NativeWidgetWin,
+ : public views::WidgetWin,
#elif defined(OS_LINUX)
: public views::WidgetGtk,
#endif
@@ -228,7 +228,7 @@ class InfoBubble
fade_away_on_close_ = fade_away_on_close;
}
// Overridden from NativeWidgetWin:
virtual void Close();
// Overridden from ui::AnimationDelegate:
@@ -256,7 +256,7 @@ class InfoBubble
virtual BorderContents* CreateBorderContents();
#if defined(OS_WIN)
// Overridden from NativeWidgetWin:
virtual void OnActivate(UINT action, BOOL minimized, HWND window);
#elif defined(OS_LINUX)
// Overridden from WidgetGtk:
@@ -142,7 +142,7 @@ class BorderWidget : public views::NativeWidgetWin {
BorderContents* border_contents_;
private:
- // Overridden from NativeWidgetWin:
+ // Overridden from WidgetWin:
virtual LRESULT OnMouseActivate(HWND window,
UINT hit_test,
@@ -228,7 +228,7 @@ class InfoBubble
fade_away_on_close_ = fade_away_on_close;
}
- // Overridden from NativeWidgetWin:
+ // Overridden from WidgetWin:
virtual void Close();
// Overridden from ui::AnimationDelegate:
@@ -256,7 +256,7 @@ class InfoBubble
virtual BorderContents* CreateBorderContents();
#if defined(OS_WIN)
- // Overridden from NativeWidgetWin:
+ // Overridden from WidgetWin:
virtual void OnActivate(UINT action, BOOL minimized, HWND window);
#elif defined(OS_LINUX)
diff --git a/chrome/browser/ui/views/tab_contents/tab_contents_view_win.h b/chrome/browser/ui/views/tab_contents/tab_contents_view_win.h
index 57950bb..fad7edc 100644
--- a/chrome/browser/ui/views/tab_contents/tab_contents_view_win.h
+++ b/chrome/browser/ui/views/tab_contents/tab_contents_view_win.h
@@ -10,7 +10,7 @@
#include "base/timer.h"
#include "chrome/browser/tab_contents/tab_contents_view.h"
#include "ui/gfx/size.h"
-#include "views/widget/native_widget_win.h"
+#include "views/widget/widget_win.h"
class RenderViewContextMenuViews;
class SadTabView;
@@ -26,7 +26,7 @@ class Point;
// Windows-specific implementation of the TabContentsView. It is a HWND that
// contains all of the contents of the tab and associated child views.
class TabContentsViewWin : public TabContentsView,
- public views::NativeWidgetWin {
+ public views::WidgetWin {
public:
// The corresponding TabContents is passed in the constructor, and manages our
// lifetime. This doesn't need to be the case, but is this way currently
@@ -75,7 +75,7 @@ class TabContentsViewWin : public TabContentsView,
virtual void GotFocus();
virtual void TakeFocus(bool reverse);
- // NativeWidgetWin overridde.
+ // WidgetWin overridde.
virtual views::FocusManager* GetFocusManager();
void EndDragging();
@@ -88,7 +88,7 @@ class TabContentsViewWin : public TabContentsView,
// Windows events ------------------------------------------------------------
// Overrides from NativeWidgetWin.
virtual void OnDestroy();
virtual void OnHScroll(int scroll_type, short position, HWND scrollbar);
virtual void OnMouseLeave();
@@ -88,7 +88,7 @@ class TabContentsViewWin : public TabContentsView,
// Windows events ------------------------------------------------------------
- // Overrides from NativeWidgetWin.
+ // Overrides from WidgetWin.
virtual void OnDestroy();
virtual void OnHScroll(int scroll_type, short position, HWND scrollbar);